@@ -3,7 +3,10 @@
 import numbers
 import typing
 
-import expenvelope
+import expenvelope  # type: ignore
+import numpy as np  # type: ignore
+
+from mutwo import utilities
 
 
 class DynamicChoice(object):
@@ -26,16 +29,12 @@ class DynamicChoice(object):
 
         assert len(values) == len(curves)
 
-        import random
-
-        random.seed(random_seed)
-
         self._values = values
         self._curves = curves
-        self._random = random
+        self._random = np.random.default_rng(random_seed)
 
     def __repr__(self) -> str:
-        return "{}({})".format(type(self).__name__, self._values)
+        return f"{type(self).__name__}({self._values})"
 
     def items(self) -> typing.Tuple[typing.Tuple[typing.Any, expenvelope.Envelope]]:
         return tuple(zip(self._values, self._curves))
@@ -47,4 +46,6 @@ class DynamicChoice(object):
         :type time: numbers.Real
         """
         weights = [curve.value_at(time) for curve in self._curves]
-        return self._random.choices(self._values, weights, k=1)[0]
+        return self._random.choice(
+            self._values, p=utilities.tools.scale_sequence_to_sum(weights, 1)
+        )
